pub struct Server { /* private fields */ }Expand description
A simple mock server for DNS requests.
The intended usage is to create a new instance using Server::default() and add some record
mappings to it. You can then bind a UdpSocket and start the server with Server::start()
in a background task before making requests on the main thread.
Implementations
Sourceimpl Server
impl Server
Sourcepub fn add_records(
&mut self,
name: &str,
records: Vec<IpAddr>,
) -> Result<(), ProtoError>
pub fn add_records( &mut self, name: &str, records: Vec<IpAddr>, ) -> Result<(), ProtoError>
Adds a mapping from a DNS record to some IP addresses.
Example
let mut server = Server::default();
let records = vec![IpAddr::V4(Ipv4Addr::LOCALHOST)];
server.add_records("example.com", records).expect("Invalid hostname");Sourcepub async fn start(self, socket: UdpSocket) -> Result<(), ProtoError>
pub async fn start(self, socket: UdpSocket) -> Result<(), ProtoError>
Starts the mock server on the given UdpSocket.
This should be run in a background task using a method such as tokio::spawn.